@@ -81,7 +81,7 @@ def main():
                 else:
                     output = file["path"]
                 print(output)
-                cmd = f"latexmk \"{file['name']}\" -interaction=nonstopmode -lualatex -output-directory=\"{os.path.join(file['path'])}\""
+                cmd = f"latexmk \"{file['name']}\" -interaction=nonstopmode -xelatex -output-directory=\"{os.path.join(file['path'])}\""
                 print(cmd)
                 subprocess.call(cmd, shell=True)
             before = after
